@@ -38,7 +38,8 @@ namespace metaproxy_1 {
         class Worker;
     public:
         ThreadPoolSocketObserver(yazpp_1::ISocketObservable *obs,
-                                 int no_threads);
+                                 unsigned min_threads, unsigned max_threads,
+                                 unsigned stack_size);
         virtual ~ThreadPoolSocketObserver();
         void put(IThreadPoolMsg *m);
         void cleanup(IThreadPoolMsg *m, void *info);
@@ -46,6 +47,7 @@ namespace metaproxy_1 {
         void run(void *p);
         void get_thread_info(int &tbusy, int &total);
     private:
+        void add_worker(void);
         void socketNotify(int event);
         boost::scoped_ptr<Rep> m_p;
 
